@@ -5,7 +5,7 @@ use warnings;
 
 use Module::Runtime;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 # ----------------------------------------------
 
@@ -60,7 +60,7 @@ __END__
 
 =head1 NAME
 
-Tree::Persist - A transparent persistence layer for L<Tree> and its children
+Tree::Persist - A transparent persistence layer for Tree and its children
 
 =head1 SYNOPSIS
 
@@ -240,6 +240,10 @@ L<Devel::Cover> report on this module's V 0.99 test suite.
 
 Email Ron Savage at the address below.
 
+=head1 REPOSITORY
+
+L<https://github.com/ronsavage/Tree-Persist>.
+
 =head1 AUTHORS
 
 Rob Kinyon E<lt>rob.kinyon@iinteractive.comE<gt>
